@@ -28,15 +28,17 @@ build_time_vars = {'ABIFLAGS': '',
            '-fstack-protector-strong -fno-plt -fexceptions         '
            '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
            '-fstack-clash-protection -g '
-           '-ffile-prefix-map=/build/python/src=/usr/src/debug -march=armv7-a '
-           '-mfloat-abi=hard -mfpu=neon -O3 -pipe -fstack-protector-strong '
-           '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-           '-Werror=format-security         -fstack-clash-protection -g '
-           '-ffile-prefix-map=/build/python/src=/usr/src/debug -march=armv7-a '
-           '-mfloat-abi=hard -mfpu=neon -O3 -pipe -fstack-protector-strong '
-           '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-           '-Werror=format-security         -fstack-clash-protection -g '
-           '-ffile-prefix-map=/build/python/src=/usr/src/debug',
+           '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+           '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+           '-fstack-protector-strong -fno-plt -fexceptions         '
+           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
+           '-fstack-clash-protection -g '
+           '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+           '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+           '-fstack-protector-strong -fno-plt -fexceptions         '
+           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
+           '-fstack-clash-protection -g '
+           '-ffile-prefix-map=/build/python/src=/usr/src/debug/python',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -46,7 +48,8 @@ build_time_vars = {'ABIFLAGS': '',
                      '-fstack-protector-strong -fno-plt -fexceptions         '
                      '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                      '-Werror=format-security         -fstack-clash-protection '
-                     '-g -ffile-prefix-map=/build/python/src=/usr/src/debug',
+                     '-g '
+                     '-ffile-prefix-map=/build/python/src=/usr/src/debug/python',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
@@ -65,7 +68,7 @@ build_time_vars = {'ABIFLAGS': '',
                 '-fstack-protector-strong -fno-plt -fexceptions         '
                 '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                 '-Werror=format-security         -fstack-clash-protection -g '
-                "-ffile-prefix-map=/build/python/src=/usr/src/debug' "
+                "-ffile-prefix-map=/build/python/src=/usr/src/debug/python' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' "
                 "'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
@@ -673,19 +676,19 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
                              '-fstack-clash-protection -g '
-                             '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                             '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                              '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 '
                              '-pipe -fstack-protector-strong -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
                              '-fstack-clash-protection -g '
-                             '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                             '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                              '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 '
                              '-pipe -fstack-protector-strong -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
                              '-fstack-clash-protection -g '
-                             '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                             '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                              '-std=c99 -Wextra -Wno-unused-result '
                              '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
@@ -697,17 +700,17 @@ build_time_vars = {'ABIFLAGS': '',
               '-fstack-protector-strong -fno-plt -fexceptions         '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
               '-Werror=format-security         -fstack-clash-protection -g '
-              '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+              '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
               '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
               '-fstack-protector-strong -fno-plt -fexceptions         '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
               '-Werror=format-security         -fstack-clash-protection -g '
-              '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+              '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
               '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
               '-fstack-protector-strong -fno-plt -fexceptions         '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
               '-Werror=format-security         -fstack-clash-protection -g '
-              '-ffile-prefix-map=/build/python/src=/usr/src/debug',
+              '-ffile-prefix-map=/build/python/src=/usr/src/debug/python',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
@@ -718,17 +721,20 @@ build_time_vars = {'ABIFLAGS': '',
                    '-fstack-protector-strong -fno-plt -fexceptions         '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-g -ffile-prefix-map=/build/python/src=/usr/src/debug '
+                   '-g '
+                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                    '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
                    '-fstack-protector-strong -fno-plt -fexceptions         '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-g -ffile-prefix-map=/build/python/src=/usr/src/debug '
+                   '-g '
+                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                    '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
                    '-fstack-protector-strong -fno-plt -fexceptions         '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-g -ffile-prefix-map=/build/python/src=/usr/src/debug '
+                   '-g '
+                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                    '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
@@ -749,19 +755,19 @@ build_time_vars = {'ABIFLAGS': '',
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                         '-Werror=format-security         '
                         '-fstack-clash-protection -g '
-                        '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                        '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                         '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
                         '-fstack-protector-strong -fno-plt '
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                         '-Werror=format-security         '
                         '-fstack-clash-protection -g '
-                        '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                        '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                         '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
                         '-fstack-protector-strong -fno-plt '
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                         '-Werror=format-security         '
                         '-fstack-clash-protection -g '
-                        '-ffile-prefix-map=/build/python/src=/usr/src/debug '
+                        '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                         '-std=c99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
